==> azle-0.7.0-rc.2.tgz: package/examples/motoko_examples/minimal-counter-dapp/webpack.config.js <==
const path = require('path');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const TerserPlugin = require('terser-webpack-plugin');

function initCanisterEnv() {
    let localCanisters, prodCanisters;
    try {
        localCanisters = require(path.resolve(
            '.dfx',
            'local',
            'canister_ids.json'
        ));
    } catch (error) {
        console.log('No local canister_ids.json found. Continuing production');
    }
    try {
        prodCanisters = require(path.resolve('canister_ids.json'));
    } catch (error) {
        console.log(
            'No production canister_ids.json found. Continuing with local'
        );
    }

    const network =
        process.env.DFX_NETWORK ||
        (process.env.NODE_ENV === 'production' ? 'ic' : 'local');

    const canisterConfig = network === 'local' ? localCanisters : prodCanisters;

    return Object.entries(canisterConfig).reduce((prev, current) => {
        const [canisterName, canisterDetails] = current;
        prev[canisterName.toUpperCase() + '_CANISTER_ID'] =
            canisterDetails[network];
        return prev;
    }, {});
}
const canisterEnvVariables = initCanisterEnv();

const isDevelopment = process.env.NODE_ENV !== 'production';

const frontendDirectory = 'minimal_dapp_assets';

const asset_entry = path.join(
    'canisters',
    frontendDirectory,
    'src',
    'index.html'
);

module.exports = {
    target: 'web',
    mode: isDevelopment ? 'development' : 'production',
    entry: {
        // The frontend.entrypoint points to the HTML file for this build, so we need
        // to replace the extension to `.js`.
        index: path.join(__dirname, asset_entry).replace(/\.html$/, '.js')
    },
    devtool: isDevelopment ? 'source-map' : false,
    optimization: {
        minimize: !isDevelopment,
        minimizer: [new TerserPlugin()]
    },
    resolve: {
        extensions: ['.js', '.ts', '.jsx', '.tsx'],
        fallback: {
            assert: require.resolve('assert/'),
            buffer: require.resolve('buffer/'),
            events: require.resolve('events/'),
            stream: require.resolve('stream-browserify/'),
            util: require.resolve('util/')
        }
    },
    output: {
        filename: 'index.js',
        path: path.join(__dirname, 'dist', frontendDirectory)
    },

    // Depending in the language or framework you are using for
    // front-end development, add module loaders to the default
    // webpack configuration. For example, if you are using React
    // modules and CSS as described in the "Adding a stylesheet"
    // tutorial, uncomment the following lines:
    // module: {
    //  rules: [
    //    { test: /\.(ts|tsx|jsx)$/, loader: "ts-loader" },
    //    { test: /\.css$/, use: ['style-loader','css-loader'] }
    //  ]
    // },
    plugins: [
        new HtmlWebpackPlugin({
            template: path.join(__dirname, asset_entry),
            cache: false
        }),
        new webpack.EnvironmentPlugin({
            NODE_ENV: 'development',
            ...canisterEnvVariables
        }),
        new webpack.ProvidePlugin({
            Buffer: [require.resolve('buffer/'), 'Buffer'],
            process: require.resolve('process/browser')
        })
    ],
    // proxy /api to port 8000 during development
    devServer: {
        proxy: {
            '/api': {
                target: 'http://localhost:8000',
                changeOrigin: true,
                pathRewrite: {
                    '^/api': '/api'
                }
            }
        },
        hot: true,
        watchFiles: [path.resolve(__dirname, 'canisters', frontendDirectory)],
        liveReload: true
    }
};

==> azle-0.21.0.tgz: package/examples/motoko_examples/minimal-counter-dapp/webpack.config.js <==
const path = require('path');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const TerserPlugin = require('terser-webpack-plugin');

function initCanisterEnv() {
    let localCanisters, prodCanisters;
    try {
        localCanisters = require(path.resolve(
            '.dfx',
            'local',
            'canister_ids.json'
        ));
    } catch (error) {
        console.log('No local canister_ids.json found. Continuing production');
    }
    try {
        prodCanisters = require(path.resolve('canister_ids.json'));
    } catch (error) {
        console.log(
            'No production canister_ids.json found. Continuing with local'
        );
    }

    const network =
        process.env.DFX_NETWORK ||
        (process.env.NODE_ENV === 'production' ? 'ic' : 'local');

    const canisterConfig = network === 'local' ? localCanisters : prodCanisters;

    return Object.entries(canisterConfig).reduce((prev, current) => {
        const [canisterName, canisterDetails] = current;
        prev[canisterName.toUpperCase() + '_CANISTER_ID'] =
            canisterDetails[network];
        return prev;
    }, {});
}
const canisterEnvVariables = initCanisterEnv();

const isDevelopment = process.env.NODE_ENV !== 'production';

const frontendDirectory = 'minimal_dapp_assets';

const asset_entry = path.join('src', frontendDirectory, 'src', 'index.html');

module.exports = {
    target: 'web',
    mode: isDevelopment ? 'development' : 'production',
    entry: {
        // The frontend.entrypoint points to the HTML file for this build, so we need
        // to replace the extension to `.js`.
        index: path.join(__dirname, asset_entry).replace(/\.html$/, '.js')
    },
    devtool: isDevelopment ? 'source-map' : false,
    optimization: {
        minimize: !isDevelopment,
        minimizer: [new TerserPlugin()]
    },
    resolve: {
        extensions: ['.js', '.ts', '.jsx', '.tsx'],
        fallback: {
            assert: require.resolve('assert/'),
            buffer: require.resolve('buffer/'),
            events: require.resolve('events/'),
            stream: require.resolve('stream-browserify/'),
            util: require.resolve('util/')
        }
    },
    output: {
        filename: 'index.js',
        path: path.join(__dirname, 'dist', frontendDirectory)
    },

    // Depending in the language or framework you are using for
    // front-end development, add module loaders to the default
    // webpack configuration. For example, if you are using React
    // modules and CSS as described in the "Adding a stylesheet"
    // tutorial, uncomment the following lines:
    // module: {
    //  rules: [
    //    { test: /\.(ts|tsx|jsx)$/, loader: "ts-loader" },
    //    { test: /\.css$/, use: ['style-loader','css-loader'] }
    //  ]
    // },
    plugins: [
        new HtmlWebpackPlugin({
            template: path.join(__dirname, asset_entry),
            cache: false
        }),
        new webpack.EnvironmentPlugin({
            NODE_ENV: 'development',
            ...canisterEnvVariables
        }),
        new webpack.ProvidePlugin({
            Buffer: [require.resolve('buffer/'), 'Buffer'],
            process: require.resolve('process/browser')
        })
    ],
    // proxy /api to port 8000 during development
    devServer: {
        proxy: {
            '/api': {
                target: 'http://localhost:8000',
                changeOrigin: true,
                pathRewrite: {
                    '^/api': '/api'
                }
            }
        },
        hot: true,
        watchFiles: [path.resolve(__dirname, 'src', frontendDirectory)],
        liveReload: true
    }
};
